Struct dicom_encoding::adapters::jpeg::JPEGAdapter
source · [−]pub struct JPEGAdapter;Trait Implementations
sourceimpl Clone for JPEGAdapter
impl Clone for JPEGAdapter
sourcefn clone(&self) -> JPEGAdapter
fn clone(&self) -> JPEGAdapter
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for JPEGAdapter
impl Debug for JPEGAdapter
sourceimpl Hash for JPEGAdapter
impl Hash for JPEGAdapter
sourceimpl Ord for JPEGAdapter
impl Ord for JPEGAdapter
sourcefn cmp(&self, other: &JPEGAdapter) -> Ordering
fn cmp(&self, other: &JPEGAdapter) -> Ordering
1.21.0 · sourceconst fn max(self, other: Self) -> Self
const fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourceconst fn min(self, other: Self) -> Self
const fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourceconst fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
const fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<JPEGAdapter> for JPEGAdapter
impl PartialEq<JPEGAdapter> for JPEGAdapter
sourcefn eq(&self, other: &JPEGAdapter) -> bool
fn eq(&self, other: &JPEGAdapter) -> bool
sourceimpl PartialOrd<JPEGAdapter> for JPEGAdapter
impl PartialOrd<JPEGAdapter> for JPEGAdapter
sourcefn partial_cmp(&self, other: &JPEGAdapter) -> Option<Ordering>
fn partial_cmp(&self, other: &JPEGAdapter) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl PixelRWAdapter for JPEGAdapter
impl PixelRWAdapter for JPEGAdapter
sourcefn decode(&self, src: &dyn PixelDataObject, dst: &mut Vec<u8>) -> DecodeResult<()>
fn decode(&self, src: &dyn PixelDataObject, dst: &mut Vec<u8>) -> DecodeResult<()>
Decode DICOM image data with jpeg encoding.
sourcefn encode(
&self,
src: &dyn PixelDataObject,
options: EncodeOptions,
dst: &mut Vec<u8>
) -> EncodeResult<()>
fn encode(
&self,
src: &dyn PixelDataObject,
options: EncodeOptions,
dst: &mut Vec<u8>
) -> EncodeResult<()>
Encode a DICOM object’s image into the format supported by this adapter,
writing a byte stream of pixel data fragment values
into the given destination. Read more
impl Copy for JPEGAdapter
impl Eq for JPEGAdapter
impl StructuralEq for JPEGAdapter
impl StructuralPartialEq for JPEGAdapter