Struct dicom_encoding::adapters::rle_lossless::RLELosslessAdapter
source · [−]pub struct RLELosslessAdapter;Trait Implementations
sourceimpl Clone for RLELosslessAdapter
impl Clone for RLELosslessAdapter
sourcefn clone(&self) -> RLELosslessAdapter
fn clone(&self) -> RLELosslessAdapter
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RLELosslessAdapter
impl Debug for RLELosslessAdapter
sourceimpl Hash for RLELosslessAdapter
impl Hash for RLELosslessAdapter
sourceimpl Ord for RLELosslessAdapter
impl Ord for RLELosslessAdapter
sourcefn cmp(&self, other: &RLELosslessAdapter) -> Ordering
fn cmp(&self, other: &RLELosslessAdapter) -> Ordering
1.21.0 · sourceconst fn max(self, other: Self) -> Self
const fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourceconst fn min(self, other: Self) -> Self
const fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourceconst fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
const fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<RLELosslessAdapter> for RLELosslessAdapter
impl PartialEq<RLELosslessAdapter> for RLELosslessAdapter
sourcefn eq(&self, other: &RLELosslessAdapter) -> bool
fn eq(&self, other: &RLELosslessAdapter) -> bool
sourceimpl PartialOrd<RLELosslessAdapter> for RLELosslessAdapter
impl PartialOrd<RLELosslessAdapter> for RLELosslessAdapter
sourcefn partial_cmp(&self, other: &RLELosslessAdapter) -> Option<Ordering>
fn partial_cmp(&self, other: &RLELosslessAdapter) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl PixelRWAdapter for RLELosslessAdapter
impl PixelRWAdapter for RLELosslessAdapter
Decode TS: 1.2.840.10008.1.2.5 (RLE Lossless)
sourcefn decode(&self, src: &dyn PixelDataObject, dst: &mut Vec<u8>) -> DecodeResult<()>
fn decode(&self, src: &dyn PixelDataObject, dst: &mut Vec<u8>) -> DecodeResult<()>
Decode the DICOM image from RLE Lossless completely.
See http://dicom.nema.org/medical/Dicom/2018d/output/chtml/part05/chapter_G.html
sourcefn encode(
&self,
src: &dyn PixelDataObject,
options: EncodeOptions,
dst: &mut Vec<u8>
) -> EncodeResult<()>
fn encode(
&self,
src: &dyn PixelDataObject,
options: EncodeOptions,
dst: &mut Vec<u8>
) -> EncodeResult<()>
Encode a DICOM object’s image into the format supported by this adapter,
writing a byte stream of pixel data fragment values
into the given destination. Read more
impl Copy for RLELosslessAdapter
impl Eq for RLELosslessAdapter
impl StructuralEq for RLELosslessAdapter
impl StructuralPartialEq for RLELosslessAdapter