Struct dicom_encoding::adapters::EncodeOptions
source · [−]Expand description
Custom options when encoding pixel data into an encapsulated form.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.quality: Option<u8>The quality of the output image as a number between 0 and 100, where 100 is the best quality that the encapsulated form can achieve and smaller values represent smaller data size with an increasingly higher error. It is ignored if the transfer syntax only supports lossless compression. If it does support lossless compression, it is expected that a quality of 100 results in a lossless encoding.
If this option is not specified, the output quality is decided automatically by the underlying adapter.
effort: Option<u8>The amount of effort that the encoder may take to encode the pixel data, as a number between 0 and 100. If supported, higher values result in better compression, at the expense of more processing time. Encoders are not required to support this option. If this option is not specified, the actual effort is decided by the underlying adapter.
Implementations
sourceimpl EncodeOptions
impl EncodeOptions