Struct dicom_encoding::adapters::RawPixelData
source · [−]Fields
fragments: C<Vec<u8>>Either a byte slice/vector if native pixel data or byte fragments if encapsulated
offset_table: C<u32>The offset table for the fragments, or empty if there is none