Module basic

Module basic 

This module provides implementations for primitive decoders of data, which may be in either Little Endian or Big Endian.

Structs

BigEndianBasicDecoder
A basic decoder of DICOM primitive elements in big endian.
LittleEndianBasicDecoder
A basic decoder of DICOM primitive elements in little endian.

Enums

BasicDecoder
A basic decoder with support for both Little Endian an Big Endian encoding, decided at run-time. Since only two values are possible, this enum may become more efficient than the use of a trait object.