Enum dicom_encoding::decode::basic::BasicDecoder
source · [−]pub enum BasicDecoder {
LE(LittleEndianBasicDecoder),
BE(BigEndianBasicDecoder),
}Expand description
A basic decoder with support for both Little Endian an Big Endian encoding, decided at run-time. Since only two values are possible, this enum may become more efficient than the use of a trait object.
Variants
LE(LittleEndianBasicDecoder)
Decode in Little Endian
BE(BigEndianBasicDecoder)
Decode in Big Endian
Implementations
sourceimpl BasicDecoder
impl BasicDecoder
sourcepub fn new(endianness: Endianness) -> Self
pub fn new(endianness: Endianness) -> Self
Create a basic decoder for the given byte order.