Enum dicom_encoding::text::DecodeTextError
source · [−]#[non_exhaustive]
pub enum DecodeTextError {
DecodeCustom {
message: Cow<'static, str>,
backtrace: Backtrace,
},
}Expand description
An error type for text decoding issues.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DecodeCustom
Fields
backtrace: BacktraceThe generated backtrace, if available.
A custom error message, for when the underlying error type does not encode error semantics into type variants.