Enum dicom_encoding::text::SpecificCharacterSet
source · [−]#[non_exhaustive]
pub enum SpecificCharacterSet {
Default,
IsoIr100,
IsoIr101,
IsoIr109,
IsoIr110,
IsoIr144,
IsoIr192,
Gb18030,
}Expand description
An enum type for all currently supported character sets.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Default
ISO-IR 6: the default character set.
IsoIr100
ISO-IR 100 (ISO-8859-1): Right-hand part of the Latin alphabet no. 1, the Western Europe character set.
IsoIr101
ISO-IR 101 (ISO-8859-2): Right-hand part of the Latin alphabet no. 2, the Central/Eastern Europe character set.
IsoIr109
ISO-IR 109 (ISO-8859-3): Right-hand part of the Latin alphabet no. 3, the South Europe character set.
IsoIr110
ISO-IR 110 (ISO-8859-4): Right-hand part of the Latin alphabet no. 4, the North Europe character set.
IsoIr144
ISO-IR 144 (ISO-8859-5): The Latin/Cyrillic character set.
IsoIr192
ISO-IR 192: The Unicode character set based on the UTF-8 encoding.
Gb18030
GB18030: The Simplified Chinese character set.
Implementations
sourceimpl SpecificCharacterSet
impl SpecificCharacterSet
sourcepub fn from_code(uid: &str) -> Option<Self>
pub fn from_code(uid: &str) -> Option<Self>
Obtain the specific character set identified by the given code string.
Supported code strings include the possible values in the respective DICOM element (0008, 0005).
Example
let character_set = SpecificCharacterSet::from_code("ISO_IR 100");
assert_eq!(character_set, Some(SpecificCharacterSet::IsoIr100));Trait Implementations
sourceimpl Clone for SpecificCharacterSet
impl Clone for SpecificCharacterSet
sourcefn clone(&self) -> SpecificCharacterSet
fn clone(&self) -> SpecificCharacterSet
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for SpecificCharacterSet
impl Debug for SpecificCharacterSet
sourceimpl Default for SpecificCharacterSet
impl Default for SpecificCharacterSet
sourceimpl Ord for SpecificCharacterSet
impl Ord for SpecificCharacterSet
sourcefn cmp(&self, other: &SpecificCharacterSet) -> Ordering
fn cmp(&self, other: &SpecificCharacterSet) -> Ordering
1.21.0 · sourceconst fn max(self, other: Self) -> Self
const fn max(self, other: Self) -> Self
1.21.0 · sourceconst fn min(self, other: Self) -> Self
const fn min(self, other: Self) -> Self
1.50.0 · sourceconst fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
const fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
sourceimpl PartialEq<SpecificCharacterSet> for SpecificCharacterSet
impl PartialEq<SpecificCharacterSet> for SpecificCharacterSet
sourcefn eq(&self, other: &SpecificCharacterSet) -> bool
fn eq(&self, other: &SpecificCharacterSet) -> bool
sourceimpl PartialOrd<SpecificCharacterSet> for SpecificCharacterSet
impl PartialOrd<SpecificCharacterSet> for SpecificCharacterSet
sourcefn partial_cmp(&self, other: &SpecificCharacterSet) -> Option<Ordering>
fn partial_cmp(&self, other: &SpecificCharacterSet) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
self and other) and is used by the <=
operator. Read more