Enum dicom_encoding::text::TextValidationOutcome
source · [−]pub enum TextValidationOutcome {
Ok,
BadCharacters,
NotOk,
}Expand description
The result of a text validation procedure (please see validate_iso_8859).
Variants
Ok
The text is fully valid and can be safely decoded.
BadCharacters
Some characters may have to be replaced, other than that the text can be safely decoded.
NotOk
The text cannot be decoded.