SpecificCharacterSet

Struct SpecificCharacterSet 

pub struct SpecificCharacterSet(/* private fields */);
A descriptor for a specific character set, taking part in text encoding and decoding as per PS3.5 ch 6 6.1.

Example

Use from_code or one of the associated constants to create a character set. From there, use the TextCodec trait to encode and decode text.

use dicom_encoding::text::{SpecificCharacterSet, TextCodec};

let character_set = SpecificCharacterSet::from_code("ISO_IR 100").unwrap();
assert_eq!(character_set, SpecificCharacterSet::ISO_IR_100);

Implementations

Source

impl SpecificCharacterSet

pub const ISO_IR_6: SpecificCharacterSet

ISO IR 6: The default character set, as defined by the DICOM standard.

pub const ISO_IR_100: SpecificCharacterSet

pub const ISO_IR_192: SpecificCharacterSet

ISO IR 192: UTF-8 encoding

pub fn from_code(code: &str) -> Option<Self>

Obtain the specific character set identified by the given code string.

Supported code strings include the possible values in the respective DICOM element (0008, 0005).

Example
use dicom_encoding::text::{SpecificCharacterSet, TextCodec};

let character_set = SpecificCharacterSet::from_code("ISO_IR 100").unwrap();
assert_eq!(character_set.name(), "ISO_IR 100");