pub enum NeverAdapter {}Expand description
An immaterial type representing a data set adapter which is never required, and as such is never instantiated. Most transfer syntaxes use this, as they do not have to adapt readers and writers for encoding and decoding data sets. The main exception is in the family of Deflated Explicit VR Little Endian transfer syntaxes.