pub struct TransferSyntaxFactory(pub fn() -> TransferSyntax);Expand description
Wrapper type for a provider of transfer syntax descriptors.
This is a piece of the plugin interface for
registering and collecting transfer syntaxes.
Implementers and consumers of transfer syntaxes
will usually not interact with it directly.
In order to register a new transfer syntax,
see the macro submit_transfer_syntax.
Tuple Fields
0: fn() -> TransferSyntaxTrait Implementations
sourceimpl Clone for TransferSyntaxFactory
impl Clone for TransferSyntaxFactory
sourcefn clone(&self) -> TransferSyntaxFactory
fn clone(&self) -> TransferSyntaxFactory
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for TransferSyntaxFactory
impl Debug for TransferSyntaxFactory
sourceimpl PartialEq<TransferSyntaxFactory> for TransferSyntaxFactory
impl PartialEq<TransferSyntaxFactory> for TransferSyntaxFactory
sourcefn eq(&self, other: &TransferSyntaxFactory) -> bool
fn eq(&self, other: &TransferSyntaxFactory) -> bool
impl Copy for TransferSyntaxFactory
impl StructuralPartialEq for TransferSyntaxFactory