[−][src]Enum dicom_encoding::text::TextValidationOutcome
The result of a text validation procedure (please see validate_iso_8859).
Variants
OkThe text is fully valid and can be safely decoded.
BadCharactersSome characters may have to be replaced, other than that the text can be safely decoded.
NotOkThe text cannot be decoded.